<?php
$lang['error_insufficientparams'] = 'Nedovoljan broj parametara (ili su neki prazni)';
$lang['error_duplicatename'] = 'Stavka sa ovim nazivom već postoji';
$lang['detail_page'] = 'Stranica za detaljan prikaz';
$lang['detail_template'] = '&Scaron;ablon za detaljan prikaz';
$lang['warning_preview'] = 'Upozorenje: Ovaj pregledni panel se pona&scaron;a slično kao prozor Veb pretraživača, omogućavajući Vam da se udaljite od stranice koju ste prvobitno pregledali. Međutim, ukoliko to uradite, može doći do neočekivanog pona&scaron;anja. Ako se udaljite od izvornog prikaza i vratite se nazad, možete dobiti neočekivane rezultate.<br/><strong>Napomena:</strong> Tokom pregleda neće biti otpremljene datoteke koje izaberete.';
$lang['article'] = 'Članak';
$lang['preview'] = 'Pregled';
$lang['info_detail_returnid'] = 'Ovo pode&scaron;avanje se koristi za određivanje stranice (a samim tim i &Scaron;ablona) koji će se koristiti pri detaljnom gledanju novosti. URL ka pojedinačnim člancima neće funkcionisati ukoliko ovaj parametar nije pode&scaron;en na validnu stranicu. Takođe, ako je ovo pode&scaron;avanje ispravno, ali parametar <code>detailpage</code> u <code>news</code> tagu nije pode&scaron;en, onda će se upotrebiti za linkove ka detaljnijim vestima.';
$lang['title_detail_returnid'] = 'Podrazumevana stranica koja će se koristiti za pregledanje detaljnih novosti';
$lang['title_submission_settings'] = 'Pode&scaron;avanja procedure objavljivanja novosti';
$lang['title_fesubmit_settings'] = 'Pode&scaron;avanje procedue objavljivanja iz korisničkog dela sajta';
$lang['title_notification_settings'] = 'Pode&scaron;avanje obave&scaron;tenja';
$lang['title_detail_settings'] = 'Pode&scaron;avanja detaljnog pregleda';
$lang['error_invalidurl'] = 'Lo&scaron; URL <em>(možda je već u upotrebi, ili sadrži nevalidne karaktere)</em>';
$lang['url'] = 'URL ';
$lang['expired_searchable'] = 'Članci kojima je važnost istekla mogu se pojaviti u rezultatima pretrage';
$lang['helpshowall'] = 'Prikaži sve članke, nezavisno od datuma prestanka važnosti';
$lang['error_invaliddates'] = 'Jedan ili vi&scaron;e unetih datuma nisu validni';
$lang['notify_n_draft_items_sub'] = '%d članak(a) novosti';
$lang['notify_n_draft_items'] = 'Imate %s koji nije/nisu objavljen(i)';
$lang['unlimited'] = 'Neograničeno';
$lang['none'] = 'Nema';
$lang['anonymous'] = 'Anoniman';
$lang['unknown'] = 'Nepoznato';
$lang['fesubmit_redirect'] = 'ID ili alijas strane na koju će korisnik biti preusmeren nakon &scaron;to objavi novi članak putem <em>fesubmit</em> akcije';
$lang['allow_summary_wysiwyg'] = 'Dozvoli upotrebu WYSIWYG editora za pisanje sažetka';
$lang['title_browsecat_template'] = 'Editor &scaron;ablona pretrage po kategoriji';
$lang['title_browsecat_sysdefault'] = 'Podrazumevani &scaron;ablon pretrage po kategoriji';
$lang['browsecattemplate'] = '&Scaron;abloni za pretragu po kategoriji';
$lang['error_filesize'] = 'Jedna otpremljena datoteka je prekoračila maksimalnu dozvoljenu veličinu';
$lang['post_date_desc'] = 'Po datumu objavljivanja u opadajućem redosledu';
$lang['post_date_asc'] = 'Po datumu objavljivanja u rastućem redosledu';
$lang['expiry_date_desc'] = 'Po datumu isteka u opadajućem redosledu';
$lang['expiry_date_asc'] = 'Po datumu isteka u rastućem redosledu';
$lang['title_desc'] = 'Po naslovu u opadajućem redosledu';
$lang['title_asc'] = 'Po naslovu u rastućem redosledu';
$lang['status_desc'] = 'Po statusu u opadajućem redosledu';
$lang['status_asc'] = 'Po statusu u rastućem redosledu';
$lang['fesubmit_status'] = 'Status članka koji je poslat preko korisničkog dela sajta';
$lang['error_invalidfiletype'] = 'Ne možete otpremiti ovu vrstu datoteke';
$lang['error_upload'] = 'Do&scaron;lo je do problema prilikom otpremanja datoteke';
$lang['error_movefile'] = 'Neuspe&scaron;no kreiranje datoteke: %s';
$lang['error_mkdir'] = 'Neuspe&scaron;no kreiranje direktorijuma: %s';
$lang['expiry_interval'] = 'Broj dana (podrazumevani) nakon kojih novost ističe (ukoliko je ta opcija čekirana)';
$lang['removed'] = 'Obrisano';
$lang['msg_contenttype_removed'] = 'Tip sadržaja <code>news</code> je uklonjen iz sistema.  Molimo da umesto njega ubacite <code>{news}</code> tagove sa odgovarajućim parametrima u &scaron;ablon ili sadržaj Va&scaron;e stranice kako biste dobili istu (ali unapređenu) funkcionalnost.';
$lang['delete_selected'] = 'Obri&scaron;i čekirane članke';
$lang['areyousure_deletemultiple'] = 'Da li ste sigurni da želite obrisati sve ove članke novosti?\nRezultat ove akcije se ne može poni&scaron;titi!';
$lang['error_templatenamexists'] = '&Scaron;ablon pod tim nazivom već postoji';
$lang['error_noarticlesselected'] = 'Nije izabran nijedan članak';
$lang['reassign_category'] = 'Promeni kategoriju u';
$lang['select'] = 'Čekiraj';
$lang['approve'] = 'Promeni status u &#039;Objavljena&#039;';
$lang['revert'] = 'Promeni status u &#039;Nacrt&#039;';
$lang['hide_summary_field'] = 'Sakrij polje za unos sažetka prilikom dodavanja ili ažuriranja članaka';
$lang['textbox'] = 'Polje za unos teksta';
$lang['checkbox'] = 'Čekboks';
$lang['textarea'] = 'Tekst boks';
$lang['file'] = 'Datoteka';
$lang['auto_create_thumbnails'] = 'Automatski kreiraj umanjene prikaze datoteka sa ovim ekstenzijama';
$lang['allowed_upload_types'] = 'Dozvoli otpremanje samo datoteka sa ovim ekstenzijama';
$lang['fielddefupdated'] = 'Definicija polja ažurirana';
$lang['editfielddef'] = 'Ažuriraj definiciju polja';
$lang['up'] = 'Gore';
$lang['down'] = 'Dole';
$lang['fielddefdeleted'] = 'Definicija polja obrisana';
$lang['nameexists'] = 'Polje pod tim nazivom već postoji';
$lang['notanumber'] = 'Vrednost za maksimalnu dužinu koju ste uneli nije broj';
$lang['fielddef'] = 'Definicija polja';
$lang['fielddefadded'] = 'Definicija polja uspe&scaron;no dodata';
$lang['public'] = 'Javno';
$lang['type'] = 'Tip';
$lang['info_maxlength'] = 'Maksimalna dužina se odnosi isključivo na polja za unos teksta';
$lang['maxlength'] = 'Maksimalna dužina';
$lang['addfielddef'] = 'Dodaj definiciju polja';
$lang['customfields'] = 'Definicije polja';
$lang['deprecated'] = 'nije podržano';
$lang['subject_newnews'] = 'Objavljen je sveži članak novosti';
$lang['email_subject'] = 'Tema odlazne e-poruke';
$lang['email_template'] = 'Format e-poruke';
$lang['formsubmit_emailaddress'] = 'E-mail adresa na koju će se slati obave&scaron;tenja o objavljivanju novih članaka';
$lang['extra'] = 'Ekstra';
$lang['uploadscategory'] = 'Kategorija otpremanja';
$lang['title_available_templates'] = 'Dostupni &scaron;abloni';
$lang['resettodefault'] = 'Resetuj na fabrička pode&scaron;avanja';
$lang['title_form_template'] = 'Editor &scaron;ablona formi';
$lang['title_detail_template'] = 'Editor &scaron;ablona detaljnog prikaza';
$lang['title_summary_template'] = 'Editor &scaron;ablona sažetog prikaza';
$lang['prompt_templatename'] = 'Naziv &scaron;ablona';
$lang['prompt_template'] = 'Izvor &scaron;ablona';
$lang['title_form_sysdefault'] = 'Podrazumevani &scaron;ablon forme';
$lang['title_summary_sysdefault'] = 'Podrazumevani &scaron;ablon sažetka';
$lang['title_detail_sysdefault'] = 'Podrazumevani &scaron;ablon detaljnog prikaza';
$lang['info_sysdefault2'] = '<strong>Napomena:</strong> Ovaj tab sadrži nekoliko tekst boksova koji Vam omogućavaju da menjate skup &scaron;ablona koji se prikažu kada kliknete na &quot;Kreiraj novi &scaron;ablon&quot;, bilo za sažetak, detaljan prikaz ili za formu. Menjanje sadržaja u ovom tabu i pritiskanje dugmeta &#039;Po&scaron;alji&#039; <strong>neće imati uticaja na bilo koji prikaz koji sada imate na sajtu</strong>. Ovi sadržaji se odnose samo na novokreirane &scaron;ablone.';
$lang['info_sysdefault'] = '(sadržaj koji se automatski ubacuje u novokreirani &scaron;ablon)';
$lang['template'] = '&Scaron;ablon';
$lang['prompt_name'] = 'Naziv';
$lang['prompt_default'] = 'Podrazumevano';
$lang['prompt_newtemplate'] = 'Kreiraj novi &scaron;ablon';
$lang['help_pagelimit'] = 'Maksimalan broj članaka koji će se prikazati (po stranici).  Ukoliko se ovaj parametar ne podesi, biće prikazani svi članci koji zadovolje dati kriterijum.  A ukoliko je parametar pode&scaron;en i broj članaka ga prevaziđe, korisniku će se omogućiti da &quot;lista&quot; rezultate putem linkova i odgovarajućeg teksta';
$lang['prompt_page'] = 'Strana';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'od';
$lang['prompt_pagelimit'] = 'Broj članaka po strani';
$lang['prompt_sorting'] = 'Sortiraj po';
$lang['title_filter'] = 'Filteri';
$lang['published'] = 'Objavljena';
$lang['draft'] = 'Nacrt';
$lang['expired'] = 'Istekla';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Vrati u prvobitno stanje';
$lang['restoretodefaultsmsg'] = 'Ova operacija će vratiti sadržaj &scaron;ablona u stanje u kom je bio nakon instalacije sistema.  Da li ste sigurni da želite sa ovim da nastavite?';
$lang['addarticle'] = 'Dodaj novost';
$lang['articleadded'] = 'Novost je uspe&scaron;no dodata.';
$lang['articleupdated'] = 'Novost je uspe&scaron;no ažurirana.';
$lang['articledeleted'] = 'Novost je uspe&scaron;no obrisana.';
$lang['addcategory'] = 'Dodaj kategoriju';
$lang['categoryadded'] = 'Kategorija je uspe&scaron;no dodata.';
$lang['categoryupdated'] = 'Kategorija je uspe&scaron;no ažurirana.';
$lang['categorydeleted'] = 'Kategorija je uspe&scaron;no obrisana.';
$lang['addnewsitem'] = 'Dodaj novost';
$lang['allcategories'] = 'Sve kategorije';
$lang['allentries'] = 'Svi članci';
$lang['areyousure'] = 'Da li ste sigurni da želite ovo obrisati?';
$lang['articles'] = 'Članci';
$lang['cancel'] = 'Otkaži';
$lang['category'] = 'Kategorija';
$lang['categories'] = 'Kategorije';
$lang['default_category'] = 'Podrazumevana kategorija';
$lang['content'] = 'Sadržaj';
$lang['dateformat'] = '%s nije validan yyyy-mm-dd hh:mm:ss format';
$lang['delete'] = 'Obri&scaron;i';
$lang['description'] = 'Dodajte, ažurirajte i bri&scaron;te novosti';
$lang['formtemplate'] = '&Scaron;abloni formi';
$lang['detailtemplate'] = '&Scaron;abloni detaljnog prikaza';
$lang['default_templates'] = 'Podrazumevani &scaron;abloni';
$lang['detailtemplateupdated'] = 'Izmenjeni &scaron;ablon detaljnog prikaza novosti je uspe&scaron;no sačuvan u bazi podataka.';
$lang['displaytemplate'] = 'Prikaži &scaron;ablon';
$lang['edit'] = 'Izmeni';
$lang['enddate'] = 'Datum isteka';
$lang['endrequiresstart'] = 'Uno&scaron;enje datuma isteka zahteva da unesete i datum početka važenja';
$lang['entries'] = '%s članak(a)';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Ističe';
$lang['filter'] = 'Filter ';
$lang['more'] = 'Jo&scaron;';
$lang['category_label'] = 'Kategorija:';
$lang['author_label'] = 'Objavio/la:';
$lang['extra_label'] = 'Ejstra:';
$lang['moretext'] = 'Jo&scaron; teksta';
$lang['name'] = 'Naziv';
$lang['news'] = 'Novosti';
$lang['news_return'] = 'Nazad';
$lang['newcategory'] = 'Nova kategorija';
$lang['needpermission'] = 'Morate imati dozvolu &#039;%s&#039; da biste izveli tu akciju.';
$lang['nocategorygiven'] = 'Nije izabrana kategorija';
$lang['startdatetoolate'] = 'Datum početka važenja je preveliki (nakon datuma isteka?)';
$lang['nocontentgiven'] = 'Nije unet sadržaj';
$lang['noitemsfound'] = '<strong>Nisu</strong> pronađeni članci u kategoriji: %s';
$lang['nopostdategiven'] = 'Nije une&scaron;en datum objavljivanja';
$lang['note'] = '<em>Napomena:</em> Datumi moraju biti u formatu &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'Nije unet naslov';
$lang['nonamegiven'] = 'Nije unet naziv';
$lang['numbertodisplay'] = 'Broj prikazanih (ukoliko je polje prazno, prikazuju se svi zapisi)';
$lang['print'] = '&Scaron;tampaj';
$lang['postdate'] = 'Datum objavljivanja';
$lang['postinstall'] = 'Make sure to set the &quot;Modify News&quot; permission on users who will be administering News items.';
$lang['selectcategory'] = 'Izaberite kategoriju';
$lang['showchildcategories'] = 'Prikaži podkategorije';
$lang['sortascending'] = 'Sortiraj u rastućem redosledu';
$lang['startdate'] = 'Datum početka važenja';
$lang['startoffset'] = 'Počni da prikazuje&scaron; od n-tog članka';
$lang['startrequiresend'] = 'Uno&scaron;enje datuma početka važenja zahteva da unesete i datum isteka';
$lang['apply'] = 'Primeni izmene';
$lang['submit'] = 'Po&scaron;alji';
$lang['summary'] = 'Sažetak';
$lang['summarytemplate'] = '&Scaron;abloni sažetaka';
$lang['summarytemplateupdated'] = '&Scaron;ablon prikaza sažetka novosti je uspe&scaron;no ažuriran';
$lang['title'] = 'Naslov';
$lang['options'] = 'Opcije';
$lang['optionsupdated'] = 'Opcije su uspe&scaron;no ažurirane.';
$lang['useexpiration'] = 'Odredi datum isticanja važnosti';
$lang['eventdesc-NewsArticleAdded'] = '&Scaron;alje se nakon objavljivanja svežeg članka.';
$lang['eventhelp-NewsArticleAdded'] = '<p>&Scaron;alje se nakon objavljivanja svežeg članka.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id članka</li>
<li>\&quot;category_id\&quot; - Id kategorije datog članka</li>
<li>\&quot;title\&quot; - Naslov članka</li>
<li>\&quot;content\&quot; - Sadržaj članka</li>
<li>\&quot;summary\&quot; - Sažetak članka</li>
<li>\&quot;status\&quot; - Status članka (&quot;nacrt&quot; ili &quot;objavljena&quot;)</li>
<li>\&quot;start_time\&quot; - Datum kada bi se novost trebala početi prikazivati</li>
<li>\&quot;end_time\&quot; - Datum kada bi će novost prestati prikazivati</li>
<li>\&quot;useexp\&quot; - Da li datum isteka važnosti treba zanemariti ili ne</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = '&Scaron;alje se nakon ažuriranja članka.';
$lang['eventhelp-NewsArticleEdited'] = '<p>&Scaron;alje se nakon ažuriranja članka.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id članka</li>
<li>\&quot;category_id\&quot; - Id kategorije datog članka</li>
<li>\&quot;title\&quot; - Naslov članka</li>
<li>\&quot;content\&quot; - Sadržaj članka</li>
<li>\&quot;summary\&quot; - Sažetak članka</li>
<li>\&quot;status\&quot; - Status članka (&quot;nacrt&quot; ili &quot;objavljena&quot;)</li>
<li>\&quot;start_time\&quot; - Datum kada bi se novost trebala početi prikazivati</li>
<li>\&quot;end_time\&quot; - Datum kada bi će novost prestati prikazivati</li>
<li>\&quot;useexp\&quot; - Da li datum isteka važnosti treba zanemariti ili ne</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = '&Scaron;alje se nakon brisanja članka';
$lang['eventhelp-NewsArticleDeleted'] = '<p>&Scaron;alje se nakon brisanja članka</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;news_id\&quot; - Id članka</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = '&Scaron;alje se nakon dodavanja nove kategorije.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>&Scaron;alje se nakon dodavanja nove kategorije.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id kategorije novosti</li>
<li>\&quot;name\&quot; - Naziv kategorije</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = '&Scaron;alje se nakon ažuriranja kategorije.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>&Scaron;alje se nakon ažuriranja kategorije.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id kategorije novosti</li>
<li>\&quot;name\&quot; - Naziv kategorije</li>
<li>\&quot;origname\&quot; - Prethodni naziv kategorije</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = '&Scaron;alje se nakon brisanja kategorije.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>&Scaron;alje se nakon brisanja kategorije.</p>
<h4>Parametri</h4>
<ul>
<li>\&quot;category_id\&quot; - Id kategorije novosti</li>
<li>\&quot;name\&quot; - Naziv obrisane kategorije</li>
</ul>
';
$lang['help_articleid'] = 'Parametar je primenljiv isključivo na detaljan prikaz novosti. Omogućava koji članci će biti prikazani u detaljnom modu. Ukoliko je pode&scaron;en na specijalnu vrednost -1, sistem će prikazivati najsvežiji, objavljeni važeći članak.';
$lang['helpnumber'] = 'Maksimalan broj članaka koji mogu biti prikazani na jednoj stranici. Ukoliko ovo polje ostavite prazno, prikazaće se svi članci. Ovo je sinonim parametra <code>pagelimit</code>';
$lang['helpstart'] = 'Počni od n-tog članka. Ukoliko ostavite ovo polje prazno, počeće se od prvog članka.';
$lang['helpcategory'] = 'Koristi se pri prikazivanju sažetaka kako bi se izdvojili članci specificiranih kategorija.   <b>Nakon naziva kategorije stavite * ukoliko želite da se prikažu i podkategorije.</b>  Vi&scaron;e kategorija se može prikazati odjednom ako njihove nazive razdvojite zarezom. Ukoliko ovo polje ostavite prazno, prikazaće se sve kategorije. Ovaj parametar funkcioni&scaron;e takođe i pri slanju novosti iz korisničkog dela sajta, ali je u tom slučaju podržan samo jedan naziv kategorije.';
$lang['helpmoretext'] = 'Tekst koji će se prikazivati na kraju novosti ako ista prekoračuje dužinu sažetka. Podrazumevana vrednost je &quot;Vi&scaron;e&quot;.';
$lang['helpsummarytemplate'] = 'Koristi zaseban &scaron;ablon iz baze podataka za prikazivanje sažetka članka. Ovaj &scaron;ablon mora postojati i biti vidljiv na tabu &scaron;ablona sažetaka u administratorskom delu Novosti, mada ne mora da bude podrazumevani &scaron;ablon. Ukoliko ovaj parametar nije određen, koristiće se podrazumevani &scaron;ablon.';
$lang['helpformtemplate'] = 'Koristi &scaron;ablon iz baze podataka za prikazivanje forme za slanje članka. Ovaj &scaron;ablon mora postojati i biti vidljiv na tabu &scaron;ablona formi za slanje novosti u administratorskom delu Novosti, mada ne mora da bude podrazumevani &scaron;ablon. Ukoliko ovaj parametar nije određen, koristiće se podrazumevani &scaron;ablon.';
$lang['helpbrowsecattemplate'] = 'Koristi &scaron;ablon iz baze podataka za prikazivanje liste kategorija. Ovaj &scaron;ablon mora postojati i biti vidljiv na tabu &scaron;ablona za pretraživanje kategorija u administratorskom delu Novosti, mada ne mora da bude podrazumevani &scaron;ablon. Ukoliko ovaj parametar nije određen, koristiće se podrazumevani &scaron;ablon.';
$lang['helpdetailtemplate'] = 'Koristi zaseban &scaron;ablon iz baze podataka za prikazivanje detalja članka. Ovaj &scaron;ablon mora postojati i biti vidljiv na tabu &scaron;ablona detaljnih prikaza u administratorskom delu Novosti, mada ne mora da bude podrazumevani &scaron;ablon. Ukoliko ovaj parametar nije određen, koristiće se podrazumevani &scaron;ablon.';
$lang['helpsortby'] = 'Polje po kom se vr&scaron;i sortiranje.  Opcije su: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  Podrazumevana vrednost je &quot;news_date&quot;. Ukoliko je navedena vrednost &quot;random&quot;, parametar sortasc će biti ignorisan.';
$lang['helpsortasc'] = 'Sortiraj novosti po datumu objavljivanja u rastućem redosledu, radije nego u opadajućem.';
$lang['helpdetailpage'] = 'Stranica na kojoj će se prikazivati detaljne novosti.  Vrednost ovog polja može biti alijas ili ID oznaka stranice. Koristi se kako bi se omogućilo prikazivanje detaljne novosti po &scaron;ablonu drukčijem og onog po kom se prikazuje sažetak.';
$lang['helpshowarchive'] = 'Prikaži samo članke čija važnost je istekla.';
$lang['helpbrowsecat'] = 'Prikazuje listu kategorija koja se može pretraživati.';
$lang['helpaction'] = 'Premo&scaron;ćuje podrazumevanu akciju.  Moguće vrednosti su:
<ul>
<li>&quot;detail&quot; - za prikazivanje detalja određenog članka.</li>
<li>&quot;default&quot; - za prikazivanje sažetka</li>
<li>&quot;fesubmit&quot; - za prikazivanje forme na javnom korisničkom delu sajta, kako bi se omogućilo korisnicima da &scaron;alju novosti.</li>
<li>&quot;browsecat&quot; - za prikazivanje liste kategorija koju je moguće pretraživati.</li>
</ul>';
$lang['help'] = '<h3>Važne napomene</h3>
<p>Od verzije 2.9 nadalje, iz modula Novosti je izbačen parametar <code>formatpostdate</code> koji se koristio u &scaron;ablonima, kao i parametar <code>dateformat</code>.  Za formatiranje datuma u svojim &scaron;ablonima biste trebali koristiti <code>cms_date_format</code> modifikator (kao &scaron;to je prikazano u fabrički pode&scaron;enim &scaron;ablonima) kao i <code>entry->postdate</code> umesto <code>entry->formatpostdate</code>.</p>
<h3>&Scaron;ta ovo radi?</h3>
<p>Novosti su modul za objavljivanje novosti (ozbiljno :) ) na Va&scaron;im stranicama u stilu sličan blogovima, samo sa vi&scaron;e mogućnosti.  Nakon instalacije modula, u administrativni meni se dodaje jo&scaron; nedna stranica, koja Vam omogućava da izaberete ili dodate kategoriju novosti. Kada kreirate ili izaberete kategoriju novosti, prikazaće se spisak novosti iz te kategorije. Potom možete dodavati, menjati ili brisati novosti u toj kategoriji.</p>
<h4>Brojni načini prikazivanja</h4>
<p>Parametri koje modul Novosti podržava, kao i podr&scaron;ka brojnim &scaron;ablonima za svaku priliku čine da su bukvalno nemate nikakvih ograničenja u načinima prikazivanja novosti.</p>
<h4>Korisnički definisana polja</h4>
<p>Modul Novosti dopu&scaron;ta definisanje sopstvenih polja (uključujući dokumente i slike) koji će Vam omogućiti da člancima dodate PDF dokumente ili brojne slike.</p>
        <h4>Kategorije</h4>
	<p>Modul pruža hijerarhijski model kategorija za organizovanje Va&scaron;ih članaka. Jedan članak može pripadati samo jednoj kategoriji.</p>
	<h4>Datum isteka i status</h4>
	<p>Za svaku novost opciono može biti definisan datum isteka važnosti, nakon kog ona vi&scaron;e neće biti prikazivana na Va&scaron;em sajtu.  Takođe, članak može biti označen i kao <em>nacrt</em> &scaron;to ga trajno uklanja sa Va&scaron;eg sajta.</p>
	<h3>Sigurnost</h3>
	<p>Korisnik mora pripadati grupi koja ima privilegiju &quot;Menjanje novosti&quot; kako bi mogao dodavati i menjati novosti.</p>
        <p>Takođe, da bi brisao članke, korisnik mora pripadati grupi koja ima privilegiju &quot;Brisanje novosti&quot;.</p>
	<p>Da bi menjao elemente izgleda novosti, korisnik mora pripadati grupi sa &quot;Menjanje &scaron;ablona&quot; privilegijom.</p>
	<p>Korisnik mora pripadati grupi sa privilegijom &quot;Menjanje pode&scaron;avanja sajta&quot; da bi menjao op&scaron;ta pode&scaron;avanja modula.</p>
	<p>Dodatno, da bi mogao odobriti da se novst pojavi na sajtu, grupi kojoj korisnik pripada mora biti dodeljena &quot;Odobravanje novosti&quot; privilegija.</p>
	<h3>Kako da ga koristim?</h3>
	<p>Najlak&scaron;i način za kori&scaron;ćenje modula je tag <code>{news}</code>.  Ovim će modul biti ubačen u Va&scaron; &scaron;ablon ili stranicu sa sadržajem, gde god želite, i prikazati novosti.  Kod bi bio sličan ovome: <code>{news number=&#039;5&#039;}</code></p>
<h3>&Scaron;abloni</h3>
<p>Od verzije 2.3 modul podržava vi&scaron;estruke &scaron;ablone iz baze podataka, ali vi&scaron;e ne podržava dodatne &scaron;ablonske datoteke.  Korisnici koji su upotrebljavali stari sistem za &scaron;ablone, trebali bi da urade sledeće (za svaku &scaron;ablonsku datoteku:</p>
<ul>
<li>Kopirajte sadržaj datoteke u Klipboard;</li>
<li>Kreirajte novi &scaron;ablon u bazi podataka <em>(za sažetak ili detaljan prikaz, po potrebi)</em>.  Dajte &scaron;ablonu isti naziv koji je imao stari &scaron;ablon (uključujući i .tpl ekstenziju) i prebacite sadržaj datoteke (Paste).</li>
<li>Kliknite na &#039;Po&scaron;alji&#039;</li>
</ul>
<p>Ovo bi trebalo da re&scaron;i problem nepronalaženja &scaron;ablona za novosti i druge slične Smarty gre&scaron;ke koje su se mogle javiti nakon &scaron;to se prebacite na verziju CMS MS-a koja sadrži verziju 2.3 modula ili noviju.</p>';
$lang['utma'] = '156861353.279934917.1335981957.1335981957.1335981957.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1335981957.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>